@@ -128,13 +128,12 @@ class ApiField(object):
                 current_object = getattr(current_object, attr, None)
 
                 if current_object is None:
-                    if self.has_default():
-                        current_object = self._default
+                    if self.null:
                         # Fall out of the loop, given any further attempts at
                         # accesses will fail miserably.
                         break
-                    elif self.null:
-                        current_object = None
+                    elif self.has_default():
+                        current_object = self._default
                         # Fall out of the loop, given any further attempts at
                         # accesses will fail miserably.
                         break
@@ -390,7 +389,7 @@ class DateTimeField(ApiField):
         if isinstance(value, six.string_types):
             try:
                 year, month, day = value[:10].split('-')
-                hour, minute, second = value[10:18].split(':')
+                hour, minute, second = value[11:19].split(':')
 
                 return make_aware(datetime_safe.datetime(int(year), int(month), int(day), int(hour), int(minute), int(second)))
             except ValueError:
@@ -641,11 +640,11 @@ class RelatedField(ApiField):
         # We also need to check to see if updates are allowed on the FK resource.
         if not obj and unique_keys:
             try:
-                fk_resource.obj_get(fk_bundle, skip_errors=True, **data)
+                fk_resource.obj_get(fk_bundle, **data)
             except (ObjectDoesNotExist, NotFound, TypeError):
                 try:
                     # Attempt lookup by primary key
-                    fk_resource.obj_get(fk_bundle, skip_errors=True, **unique_keys)
+                    fk_resource.obj_get(fk_bundle, **unique_keys)
                 except (ObjectDoesNotExist, NotFound):
                     pass
             except MultipleObjectsReturned:
@@ -851,13 +850,12 @@ class ToManyField(RelatedField):
                 except ObjectDoesNotExist:
                     the_m2ms = None
 
-                if not the_m2ms:
+                if the_m2ms is None:
                     break
 
-        if not the_m2ms:
+        if the_m2ms is None:
             if not self.null:
                 raise ApiFieldError("The model '%r' has an empty attribute '%s' and doesn't allow a null value." % (previous_obj, attr))
-
             return []
 
         if isinstance(the_m2ms, models.Manager):
