@@ -11,7 +11,8 @@ from django.utils.encoding import force_text, smart_bytes
 from django.core.serializers import json as djangojson
 
 from tastypie.bundle import Bundle
-from tastypie.exceptions import BadRequest, UnsupportedFormat
+from tastypie.exceptions import BadRequest, UnsupportedSerializationFormat,\
+    UnsupportedDeserializationFormat
 from tastypie.utils import format_datetime, format_date, format_time,\
     make_naive
 
@@ -69,6 +70,17 @@ if yaml is not None:
             Resolver.__init__(self)
 
 
+def _get_default_formats():
+    formats = ['json']
+    if lxml:
+        formats.append('xml')
+    if yaml:
+        formats.append('yaml')
+    if biplist:
+        formats.append('plist')
+    return formats
+
+
 _NUM = 0
 _DICT = 1
 _LIST = 2
@@ -107,14 +119,14 @@ class Serializer(object):
         * jsonp (Disabled by default)
         * xml
         * yaml
-        * plist (see http://explorapp.com/biplist/)
+        * plist (see https://bitbucket.org/wooster/biplist)
 
     It was designed to make changing behavior easy, either by overridding the
     various format methods (i.e. ``to_json``), by changing the
     ``formats/content_types`` options or by altering the other hook methods.
     """
 
-    formats = ['json', 'xml', 'yaml', 'plist']
+    formats = _get_default_formats()
 
     content_types = {
         'json': 'application/json',
@@ -248,7 +260,7 @@ class Serializer(object):
         method = self._to_methods.get(format)
 
         if method is None:
-            raise UnsupportedFormat("The format indicated '%s' had no available serialization method. Please check your ``formats`` and ``content_types`` on your Serializer." % format)
+            raise UnsupportedSerializationFormat(format)
 
         return method(bundle, options)
 
@@ -264,7 +276,7 @@ class Serializer(object):
         method = self._from_methods.get(format)
 
         if method is None:
-            raise UnsupportedFormat("The format indicated '%s' had no available deserialization method. Please check your ``formats`` and ``content_types`` on your Serializer." % format)
+            raise UnsupportedDeserializationFormat(format)
 
         if isinstance(content, six.binary_type):
             content = force_text(content)
